@@ -24,17 +24,16 @@ This class is a L<DBICx::Modeler|DBICx::Modeler> model.
 
 =over 4
 
-=item MORIYA Masaki (a.k.a. Gardejo)
+=item MORIYA Masaki, alias Gardejo
 
-C<< <moriya at ermitejo dot com> >>,
-L<http://ttt.ermitejo.com/>
+C<< <moriya at cpan dot org> >>,
+L<http://gardejo.org/>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2009 by MORIYA Masaki (a.k.a. Gardejo),
-L<http://ttt.ermitejo.com>.
+Copyright (c) 2009-2010 MORIYA Masaki, alias Gardejo
 
 This module is free software;
 you can redistribute it and/or modify it under the same terms as Perl itself.
